aboutsummaryrefslogtreecommitdiffstats
path: root/config/hypr/initial-boot.sh
diff options
context:
space:
mode:
authorJa.KooLit <jimmielovejay@gmail.com>2023-12-08 00:31:54 +0900
committerGitHub <noreply@github.com>2023-12-08 00:31:54 +0900
commit42b449c2bf2c54c5b3f7658f166197dcadf5cd3d (patch)
tree5aaa03534a95efa95358f4745f9863a1a892e011 /config/hypr/initial-boot.sh
parent55a3cfbd7974bca5e8545f28bb4b6bcec1b69342 (diff)
parent0d5617b7f25101bdfee905106eaa898e4dc4f93f (diff)
Merge pull request #54 from JaKooLit/main
update from mainstream
Diffstat (limited to 'config/hypr/initial-boot.sh')
-rwxr-xr-x[-rw-r--r--]config/hypr/initial-boot.sh49
1 files changed, 29 insertions, 20 deletions
diff --git a/config/hypr/initial-boot.sh b/config/hypr/initial-boot.sh
index d5ce3233..797f49cb 100644..100755
--- a/config/hypr/initial-boot.sh
+++ b/config/hypr/initial-boot.sh
@@ -1,30 +1,39 @@
#!/bin/bash
-# THIS SCRIPT CAN BE DELETED ONCE BOOTED!!
+# A bash script designed to run only once dotfiles installed
+
+# THIS SCRIPT CAN BE DELETED ONCE SUCCESSFULLY BOOTED!! And also, edit ~/.config/hypr/configs/Execs.conf
+# not necessary to do since this script is only designed to run only once as long as the marker exists
+
+# Variables
+scriptsDir=$HOME/.config/hypr/scripts
+wallpaper=$HOME/Pictures/wallpapers/anime-girl-abyss.png
+
+swww="swww img"
+effect="--transition-bezier .43,1.19,1,.4 --transition-fps 60 --transition-type grow --transition-pos 0.925,0.977 --transition-duration 2"
-# A bash script designed to ran it only once dotfiles installed
# Check if a marker file exists.
if [ ! -f ~/.config/hypr/.initial_startup_done ]; then
- # Check if the ~/.cache/wal directory exists
- if [ ! -d ~/.cache/wal ]; then
- printf " Initializing pywal........\n\n"
- # Check if the ~/Pictures/wallpapers directory exists
- if [ -d ~/Pictures/wallpapers ]; then
- # Run wal with random wallpapers from ~/Pictures/wallpapers
- wal -i ~/Pictures/wallpapers/mecha-nostalgia.png
- echo "Pywal initialized"
- fi
- fi
+ # Initialize pywal
+ printf " Initializing pywal........\n\n"
+ wal -i "$wallpaper"
+
+ # Initial symlink for Pywal Dark and Light for Rofi Themes
+ ln -sf "$HOME/.cache/wal/colors-rofi-dark.rasi" "$HOME/.config/rofi/pywal-color/pywal-theme.rasi"
+
+ # Initial scripts to load in order to have a proper wallpaper waybar and pywal themes
+ pkill swww && swww init || swww query && $swww "$wallpaper" $effect
+
+ # Refreshing waybar, dunst, rofi etc.
+ "$scriptsDir/PywalSwww.sh" > /dev/null 2>&1 &
+ "$scriptsDir/Refresh.sh" > /dev/null 2>&1 &
+
+ # initiate the kb_layout (for some reason) waybar cant launch it
+ "$scriptsDir/SwitchKeyboardLayout.sh" > /dev/null 2>&1 &
- #initial symlink for Pywal Dark and Light for Rofi Themes
- ln -sf "$HOME/.cache/wal/colors-rofi-dark.rasi" "$HOME/.config/rofi/pywal-color/pywal-theme.rasi"
-
- # Initial scripts to load inorder to have a proper wallpaper waybar and pywal themes
- exec $HOME/.config/hypr/scripts/Wallpaper.sh &
-
# Create a marker file to indicate that the script has been executed.
touch ~/.config/hypr/.initial_startup_done
-fi
-
+ exit
+fi
send patches to the email below
yukais@pinapelz.com
include the subject [PATCH repo_name]
pinapelz.com
homepage